Class: SportsOddsAPI::Models::EventGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SportsOddsAPI::Models::EventGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sports_odds_api/models/event_get_params.rb,
sig/sports_odds_api/models/event_get_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::SportsOddsAPI
Instance Attribute Summary collapse
-
#bookmaker_id ⇒ String?
A bookmakerID or comma-separated list of bookmakerIDs to include odds for.
-
#cancelled ⇒ Boolean?
Only include cancelled Events (true), only non-cancelled Events (false) or all Events (omit).
-
#cursor ⇒ String?
The cursor for the request.
-
#ended ⇒ Boolean?
Only include Events which have have ended (true), only Events which have not ended (false) or all Events (omit).
-
#event_id ⇒ String?
An eventID to get Event data for.
-
#event_ids ⇒ String?
A comma separated list of eventIDs to get Event data for.
-
#expand_results ⇒ Boolean?
Whether to expand the results object to include all stat values rather than just the base set.
-
#finalized ⇒ Boolean?
Only include finalized Events (true), exclude unfinalized Events (false) or all Events (omit).
-
#include_alt_lines ⇒ Boolean?
Whether to include alternate lines in the odds byBookmaker data.
-
#include_open_close_odds ⇒ Boolean?
Whether to include open and close odds values (openOdds, closeOdds, openSpread, closeSpread, openOverUnder, closeOverUnder) in the odds byBookmaker data.
-
#include_opposing_odds ⇒ Boolean?
Whether to include opposing odds for each included oddID.
-
#league_id ⇒ String?
A leagueID or comma-separated list of leagueIDs to get Events for.
-
#limit ⇒ Float?
The maximum number of Events to return.
-
#live ⇒ Boolean?
Only include live Events (true), only non-live Events (false) or all Events (omit).
-
#odd_id ⇒ String?
An oddID or comma-separated list of oddIDs to include odds for.
-
#odds_available ⇒ Boolean?
Whether you want only Events which do (true) or do not (false) have odds markets which are currently available (open for wagering).
-
#odds_present ⇒ Boolean?
Whether you want only Events which do (true) or do not (false) have any associated odds markets regardless of whether those odds markets are currently available (open for wagering).
-
#player_id ⇒ String?
A playerID or comma-separated list of playerIDs to include Events (and associated odds) for.
-
#sport_id ⇒ String?
A sportID or comma-separated list of sportIDs to get Events for.
-
#started ⇒ Boolean?
Only include Events which have have previously started (true), only Events which have not previously started (false) or all Events (omit).
-
#starts_after ⇒ Time?
Get Events that start after this date.
-
#starts_before ⇒ Time?
Get Events that start before this date.
-
#team_id ⇒ String?
A teamID or comma-separated list of teamIDs to include Events for.
-
#type ⇒ String?
Only include Events of the specified type.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(bookmaker_id: nil, cancelled: nil, cursor: nil, ended: nil, event_id: nil, event_ids: nil, expand_results: nil, finalized: nil, include_alt_lines: nil, include_open_close_odds: nil, include_opposing_odds: nil, league_id: nil, limit: nil, live: nil, odd_id: nil, odds_available: nil, odds_present: nil, player_id: nil, sport_id: nil, started: nil, starts_after: nil, starts_before: nil, team_id: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventGetParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bookmaker_id: nil, cancelled: nil, cursor: nil, ended: nil, event_id: nil, event_ids: nil, expand_results: nil, finalized: nil, include_alt_lines: nil, include_open_close_odds: nil, include_opposing_odds: nil, league_id: nil, limit: nil, live: nil, odd_id: nil, odds_available: nil, odds_present: nil, player_id: nil, sport_id: nil, started: nil, starts_after: nil, starts_before: nil, team_id: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SportsOddsAPI::Models::EventGetParams for more details.
|
|
# File 'lib/sports_odds_api/models/event_get_params.rb', line 166
|
Instance Attribute Details
#bookmaker_id ⇒ String?
A bookmakerID or comma-separated list of bookmakerIDs to include odds for
14 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 14 optional :bookmaker_id, String |
#cancelled ⇒ Boolean?
Only include cancelled Events (true), only non-cancelled Events (false) or all Events (omit)
21 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 21 optional :cancelled, SportsOddsAPI::Internal::Type::Boolean |
#cursor ⇒ String?
The cursor for the request. Used to get the next group of Events. This is an opaque token — pass the nextCursor value from the prior response unchanged.
28 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 28 optional :cursor, String |
#ended ⇒ Boolean?
Only include Events which have have ended (true), only Events which have not ended (false) or all Events (omit)
35 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 35 optional :ended, SportsOddsAPI::Internal::Type::Boolean |
#event_id ⇒ String?
An eventID to get Event data for
41 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 41 optional :event_id, String |
#event_ids ⇒ String?
A comma separated list of eventIDs to get Event data for
47 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 47 optional :event_ids, String |
#expand_results ⇒ Boolean?
Whether to expand the results object to include all stat values rather than just the base set
54 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 54 optional :expand_results, SportsOddsAPI::Internal::Type::Boolean |
#finalized ⇒ Boolean?
Only include finalized Events (true), exclude unfinalized Events (false) or all Events (omit)
61 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 61 optional :finalized, SportsOddsAPI::Internal::Type::Boolean |
#include_alt_lines ⇒ Boolean?
Whether to include alternate lines in the odds byBookmaker data
67 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 67 optional :include_alt_lines, SportsOddsAPI::Internal::Type::Boolean |
#include_open_close_odds ⇒ Boolean?
Whether to include open and close odds values (openOdds, closeOdds, openSpread, closeSpread, openOverUnder, closeOverUnder) in the odds byBookmaker data
74 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 74 optional :include_open_close_odds, SportsOddsAPI::Internal::Type::Boolean |
#include_opposing_odds ⇒ Boolean?
Whether to include opposing odds for each included oddID
80 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 80 optional :include_opposing_odds, SportsOddsAPI::Internal::Type::Boolean |
#league_id ⇒ String?
A leagueID or comma-separated list of leagueIDs to get Events for
86 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 86 optional :league_id, String |
#limit ⇒ Float?
The maximum number of Events to return
92 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 92 optional :limit, Float |
#live ⇒ Boolean?
Only include live Events (true), only non-live Events (false) or all Events (omit)
99 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 99 optional :live, SportsOddsAPI::Internal::Type::Boolean |
#odd_id ⇒ String?
An oddID or comma-separated list of oddIDs to include odds for
105 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 105 optional :odd_id, String |
#odds_available ⇒ Boolean?
Whether you want only Events which do (true) or do not (false) have odds markets which are currently available (open for wagering)
112 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 112 optional :odds_available, SportsOddsAPI::Internal::Type::Boolean |
#odds_present ⇒ Boolean?
Whether you want only Events which do (true) or do not (false) have any associated odds markets regardless of whether those odds markets are currently available (open for wagering)
120 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 120 optional :odds_present, SportsOddsAPI::Internal::Type::Boolean |
#player_id ⇒ String?
A playerID or comma-separated list of playerIDs to include Events (and associated odds) for
127 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 127 optional :player_id, String |
#sport_id ⇒ String?
A sportID or comma-separated list of sportIDs to get Events for
133 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 133 optional :sport_id, String |
#started ⇒ Boolean?
Only include Events which have have previously started (true), only Events which have not previously started (false) or all Events (omit)
140 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 140 optional :started, SportsOddsAPI::Internal::Type::Boolean |
#starts_after ⇒ Time?
Get Events that start after this date
146 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 146 optional :starts_after, Time |
#starts_before ⇒ Time?
Get Events that start before this date
152 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 152 optional :starts_before, Time |
#team_id ⇒ String?
A teamID or comma-separated list of teamIDs to include Events for
158 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 158 optional :team_id, String |
#type ⇒ String?
Only include Events of the specified type
164 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 164 optional :type, String |
Instance Method Details
#to_hash ⇒ {
160 |
# File 'sig/sports_odds_api/models/event_get_params.rbs', line 160
def to_hash: -> {
|