Class: SportsOddsAPI::Models::Market::Support

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/sports_odds_api/models/market.rb,
sig/sports_odds_api/models/market.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(supported: nil) ⇒ Support

Some parameter documentations has been truncated, see SportsOddsAPI::Models::Market::Support for more details.

Parameters:

  • supported (Boolean) (defaults to: nil)

    Whether this market is supported for the given league and bookmaker combination.

  • supported: (Boolean) (defaults to: nil)


# File 'lib/sports_odds_api/models/market.rb', line 198

Instance Attribute Details

#supportedBoolean?

Whether this market is supported for the given league and bookmaker combination.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


196
# File 'lib/sports_odds_api/models/market.rb', line 196

optional :supported, SportsOddsAPI::Internal::Type::Boolean

Instance Method Details

#to_hash{ supported: bool }

Returns:

  • ({ supported: bool })


182
# File 'sig/sports_odds_api/models/market.rbs', line 182

def to_hash: -> { supported: bool }