Class: SportsOddsAPI::Models::MarketGetParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/sports_odds_api/models/market_get_params.rb,
sig/sports_odds_api/models/market_get_params.rbs

Overview

See Also:

  • SportsOddsAPI::Resources::Markets#get

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::SportsOddsAPI

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bet_type_id: nil, bookmaker_id: nil, cursor: nil, is_main_market: nil, is_prop: nil, is_sub_period: nil, is_supported: nil, league_id: nil, limit: nil, odd_id: nil, period_id: nil, prop_type: nil, side_id: nil, sport_id: nil, stat_entity_id: nil, stat_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see SportsOddsAPI::Models::MarketGetParams for more details.

Parameters:

  • bet_type_id (String) (defaults to: nil)

    A single betTypeID or comma-separated list of betTypeIDs to filter Markets by

  • bookmaker_id (String) (defaults to: nil)

    A single bookmakerID or comma-separated list of bookmakerIDs to filter Markets b

  • cursor (String) (defaults to: nil)

    The cursor for pagination. Use nextCursor from prior response.

  • is_main_market (Boolean) (defaults to: nil)

    Filter to only include main markets (main period moneyline, spread, and over/und

  • is_prop (Boolean) (defaults to: nil)

    Filter by whether it is any type of prop bet market

  • is_sub_period (Boolean) (defaults to: nil)

    Filter by whether it tracks a sub/non-main period

  • is_supported (Boolean) (defaults to: nil)

    Filter whether this market is fully supported by at least 1 bookmaker in at leas

  • league_id (String) (defaults to: nil)

    A single leagueID or comma-separated list of leagueIDs to filter Markets by

  • limit (Float) (defaults to: nil)

    The maximum number of Markets to return (default: 100, max: 10000)

  • odd_id (String) (defaults to: nil)

    A single oddID or comma-separated list of oddIDs. Used to specify specific Marke

  • period_id (String) (defaults to: nil)

    A single periodID or comma-separated list of periodIDs to filter Markets by

  • prop_type (String) (defaults to: nil)

    Filter by prop type (game_prop, team_prop, player_prop, other_prop)

  • side_id (String) (defaults to: nil)

    A single sideID or comma-separated list of sideIDs to filter Markets by

  • sport_id (String) (defaults to: nil)

    A single sportID or comma-separated list of sportIDs to filter Markets by

  • stat_entity_id (String) (defaults to: nil)

    A single statEntityID or comma-separated list of statEntityIDs to filter Markets

  • stat_id (String) (defaults to: nil)

    A single statID or comma-separated list of statIDs to filter Markets by

  • request_options (SportsOddsAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/sports_odds_api/models/market_get_params.rb', line 111

Instance Attribute Details

#bet_type_idString?

A single betTypeID or comma-separated list of betTypeIDs to filter Markets by

Parameters:

  • (String)

Returns:

  • (String, nil)


14
# File 'lib/sports_odds_api/models/market_get_params.rb', line 14

optional :bet_type_id, String

#bookmaker_idString?

A single bookmakerID or comma-separated list of bookmakerIDs to filter Markets by

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/sports_odds_api/models/market_get_params.rb', line 21

optional :bookmaker_id, String

#cursorString?

The cursor for pagination. Use nextCursor from prior response.

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/sports_odds_api/models/market_get_params.rb', line 27

optional :cursor, String

#is_main_marketBoolean?

Filter to only include main markets (main period moneyline, spread, and over/under)

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


34
# File 'lib/sports_odds_api/models/market_get_params.rb', line 34

optional :is_main_market, SportsOddsAPI::Internal::Type::Boolean

#is_propBoolean?

Filter by whether it is any type of prop bet market

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


40
# File 'lib/sports_odds_api/models/market_get_params.rb', line 40

optional :is_prop, SportsOddsAPI::Internal::Type::Boolean

#is_sub_periodBoolean?

Filter by whether it tracks a sub/non-main period

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


46
# File 'lib/sports_odds_api/models/market_get_params.rb', line 46

optional :is_sub_period, SportsOddsAPI::Internal::Type::Boolean

#is_supportedBoolean?

Filter whether this market is fully supported by at least 1 bookmaker in at least 1 league. Defaults to true if not specified.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


53
# File 'lib/sports_odds_api/models/market_get_params.rb', line 53

optional :is_supported, SportsOddsAPI::Internal::Type::Boolean

#league_idString?

A single leagueID or comma-separated list of leagueIDs to filter Markets by

Parameters:

  • (String)

Returns:

  • (String, nil)


59
# File 'lib/sports_odds_api/models/market_get_params.rb', line 59

optional :league_id, String

#limitFloat?

The maximum number of Markets to return (default: 100, max: 10000)

Parameters:

  • (Float)

Returns:

  • (Float, nil)


65
# File 'lib/sports_odds_api/models/market_get_params.rb', line 65

optional :limit, Float

#odd_idString?

A single oddID or comma-separated list of oddIDs. Used to specify specific Markets to return.

Parameters:

  • (String)

Returns:

  • (String, nil)


72
# File 'lib/sports_odds_api/models/market_get_params.rb', line 72

optional :odd_id, String

#period_idString?

A single periodID or comma-separated list of periodIDs to filter Markets by

Parameters:

  • (String)

Returns:

  • (String, nil)


78
# File 'lib/sports_odds_api/models/market_get_params.rb', line 78

optional :period_id, String

#prop_typeString?

Filter by prop type (game_prop, team_prop, player_prop, other_prop)

Parameters:

  • (String)

Returns:

  • (String, nil)


84
# File 'lib/sports_odds_api/models/market_get_params.rb', line 84

optional :prop_type, String

#side_idString?

A single sideID or comma-separated list of sideIDs to filter Markets by

Parameters:

  • (String)

Returns:

  • (String, nil)


90
# File 'lib/sports_odds_api/models/market_get_params.rb', line 90

optional :side_id, String

#sport_idString?

A single sportID or comma-separated list of sportIDs to filter Markets by

Parameters:

  • (String)

Returns:

  • (String, nil)


96
# File 'lib/sports_odds_api/models/market_get_params.rb', line 96

optional :sport_id, String

#stat_entity_idString?

A single statEntityID or comma-separated list of statEntityIDs to filter Markets by

Parameters:

  • (String)

Returns:

  • (String, nil)


103
# File 'lib/sports_odds_api/models/market_get_params.rb', line 103

optional :stat_entity_id, String

#stat_idString?

A single statID or comma-separated list of statIDs to filter Markets by

Parameters:

  • (String)

Returns:

  • (String, nil)


109
# File 'lib/sports_odds_api/models/market_get_params.rb', line 109

optional :stat_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


112
# File 'sig/sports_odds_api/models/market_get_params.rbs', line 112

def to_hash: -> {