Class: SportsOddsAPI::Models::EventGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SportsOddsAPI::Models::EventGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sports_odds_api/models/event_get_params.rb,
sig/sports_odds_api/models/event_get_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::SportsOddsAPI
Instance Attribute Summary collapse
-
#bookmaker_id ⇒ String?
A bookmakerID or comma-separated list of bookmakerIDs to include odds for.
-
#cancelled ⇒ Boolean?
Only include cancelled Events (true), only non-cancelled Events (false) or all Events (omit).
-
#cursor ⇒ String?
The cursor for the request.
-
#ended ⇒ Boolean?
Only include Events which have have ended (true), only Events which have not ended (false) or all Events (omit).
-
#event_id ⇒ String?
An eventID to get Event data for.
-
#event_ids ⇒ String?
A comma separated list of eventIDs to get Event data for.
-
#finalized ⇒ Boolean?
Only include finalized Events (true), exclude unfinalized Events (false) or all Events (omit).
-
#include_alt_lines ⇒ Boolean?
Whether to include alternate lines in the odds byBookmaker data.
-
#include_opposing_odds ⇒ Boolean?
Whether to include opposing odds for each included oddID.
-
#league_id ⇒ String?
A leagueID or comma-separated list of leagueIDs to get Events for.
-
#limit ⇒ Float?
The maximum number of Events to return.
-
#live ⇒ Boolean?
Only include live Events (true), only non-live Events (false) or all Events (omit).
-
#odd_id ⇒ String?
An oddID or comma-separated list of oddIDs to include odds for.
-
#odds_available ⇒ Boolean?
Whether you want only Events which do (true) or do not (false) have odds markets which are currently available (open for wagering).
-
#odds_present ⇒ Boolean?
Whether you want only Events which do (true) or do not (false) have any associated odds markets regardless of whether those odds markets are currently available (open for wagering).
-
#player_id ⇒ String?
A playerID or comma-separated list of playerIDs to include Events (and associated odds) for.
-
#sport_id ⇒ String?
A sportID or comma-separated list of sportIDs to get Events for.
-
#started ⇒ Boolean?
Only include Events which have have previously started (true), only Events which have not previously started (false) or all Events (omit).
-
#starts_after ⇒ Time?
Get Events that start after this date.
-
#starts_before ⇒ Time?
Get Events that start before this date.
-
#team_id ⇒ String?
A teamID or comma-separated list of teamIDs to include Events for.
-
#type ⇒ String?
Only include Events of the specified type.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(bookmaker_id: nil, cancelled: nil, cursor: nil, ended: nil, event_id: nil, event_ids: nil, finalized: nil, include_alt_lines: nil, include_opposing_odds: nil, league_id: nil, limit: nil, live: nil, odd_id: nil, odds_available: nil, odds_present: nil, player_id: nil, sport_id: nil, started: nil, starts_after: nil, starts_before: nil, team_id: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventGetParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bookmaker_id: nil, cancelled: nil, cursor: nil, ended: nil, event_id: nil, event_ids: nil, finalized: nil, include_alt_lines: nil, include_opposing_odds: nil, league_id: nil, limit: nil, live: nil, odd_id: nil, odds_available: nil, odds_present: nil, player_id: nil, sport_id: nil, started: nil, starts_after: nil, starts_before: nil, team_id: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SportsOddsAPI::Models::EventGetParams for more details.
|
|
# File 'lib/sports_odds_api/models/event_get_params.rb', line 152
|
Instance Attribute Details
#bookmaker_id ⇒ String?
A bookmakerID or comma-separated list of bookmakerIDs to include odds for
14 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 14 optional :bookmaker_id, String |
#cancelled ⇒ Boolean?
Only include cancelled Events (true), only non-cancelled Events (false) or all Events (omit)
21 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 21 optional :cancelled, SportsOddsAPI::Internal::Type::Boolean |
#cursor ⇒ String?
The cursor for the request. Used to get the next group of Events. This should be the nextCursor from the prior response.
28 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 28 optional :cursor, String |
#ended ⇒ Boolean?
Only include Events which have have ended (true), only Events which have not ended (false) or all Events (omit)
35 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 35 optional :ended, SportsOddsAPI::Internal::Type::Boolean |
#event_id ⇒ String?
An eventID to get Event data for
41 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 41 optional :event_id, String |
#event_ids ⇒ String?
A comma separated list of eventIDs to get Event data for
47 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 47 optional :event_ids, String |
#finalized ⇒ Boolean?
Only include finalized Events (true), exclude unfinalized Events (false) or all Events (omit)
54 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 54 optional :finalized, SportsOddsAPI::Internal::Type::Boolean |
#include_alt_lines ⇒ Boolean?
Whether to include alternate lines in the odds byBookmaker data
60 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 60 optional :include_alt_lines, SportsOddsAPI::Internal::Type::Boolean |
#include_opposing_odds ⇒ Boolean?
Whether to include opposing odds for each included oddID
66 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 66 optional :include_opposing_odds, SportsOddsAPI::Internal::Type::Boolean |
#league_id ⇒ String?
A leagueID or comma-separated list of leagueIDs to get Events for
72 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 72 optional :league_id, String |
#limit ⇒ Float?
The maximum number of Events to return
78 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 78 optional :limit, Float |
#live ⇒ Boolean?
Only include live Events (true), only non-live Events (false) or all Events (omit)
85 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 85 optional :live, SportsOddsAPI::Internal::Type::Boolean |
#odd_id ⇒ String?
An oddID or comma-separated list of oddIDs to include odds for
91 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 91 optional :odd_id, String |
#odds_available ⇒ Boolean?
Whether you want only Events which do (true) or do not (false) have odds markets which are currently available (open for wagering)
98 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 98 optional :odds_available, SportsOddsAPI::Internal::Type::Boolean |
#odds_present ⇒ Boolean?
Whether you want only Events which do (true) or do not (false) have any associated odds markets regardless of whether those odds markets are currently available (open for wagering)
106 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 106 optional :odds_present, SportsOddsAPI::Internal::Type::Boolean |
#player_id ⇒ String?
A playerID or comma-separated list of playerIDs to include Events (and associated odds) for
113 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 113 optional :player_id, String |
#sport_id ⇒ String?
A sportID or comma-separated list of sportIDs to get Events for
119 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 119 optional :sport_id, String |
#started ⇒ Boolean?
Only include Events which have have previously started (true), only Events which have not previously started (false) or all Events (omit)
126 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 126 optional :started, SportsOddsAPI::Internal::Type::Boolean |
#starts_after ⇒ Time?
Get Events that start after this date
132 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 132 optional :starts_after, Time |
#starts_before ⇒ Time?
Get Events that start before this date
138 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 138 optional :starts_before, Time |
#team_id ⇒ String?
A teamID or comma-separated list of teamIDs to include Events for
144 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 144 optional :team_id, String |
#type ⇒ String?
Only include Events of the specified type
150 |
# File 'lib/sports_odds_api/models/event_get_params.rb', line 150 optional :type, String |
Instance Method Details
#to_hash ⇒ {
148 |
# File 'sig/sports_odds_api/models/event_get_params.rbs', line 148
def to_hash: -> {
|