Class: SportsOddsAPI::Models::StatGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- SportsOddsAPI::Models::StatGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/sports_odds_api/models/stat_get_params.rb,
sig/sports_odds_api/models/stat_get_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::SportsOddsAPI
Instance Attribute Summary collapse
-
#sport_id ⇒ String?
SportID to get StatIDs for.
-
#stat_id ⇒ String?
StatID to get data for.
-
#stat_level ⇒ String?
Level of the stat, must be used in combination with sportID.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(sport_id: nil, stat_id: nil, stat_level: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see StatGetParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(sport_id: nil, stat_id: nil, stat_level: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see SportsOddsAPI::Models::StatGetParams for more details.
|
|
# File 'lib/sports_odds_api/models/stat_get_params.rb', line 30
|
Instance Attribute Details
#sport_id ⇒ String?
SportID to get StatIDs for
14 |
# File 'lib/sports_odds_api/models/stat_get_params.rb', line 14 optional :sport_id, String |
#stat_id ⇒ String?
StatID to get data for
20 |
# File 'lib/sports_odds_api/models/stat_get_params.rb', line 20 optional :stat_id, String |
#stat_level ⇒ String?
Level of the stat, must be used in combination with sportID. Must be one of all, player, or team. Shows stats that are applicable to that specified entity, defaults to all.
28 |
# File 'lib/sports_odds_api/models/stat_get_params.rb', line 28 optional :stat_level, String |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/sports_odds_api/models/stat_get_params.rbs', line 30
def to_hash: -> {
|